# Copyright (c) 2014 Dan Frey <dafrey@cisco.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# Installation Steps
# Place this file on the router media, typically the flash drive.
# Date: May 28, 2014
# Summary - This is a tclsh script that is managed by an EEM applet.   
# The script reads in the NMEA IP data and writes it to a UDP socket
# in order to support UDP streaming of the NMEA data.  Configure NMEA under
# "controler Cellular 0" for IP.  
# "package require udp" is not available under EEM with TCL.
# 
# EEM applet to manage the TCL script:
#
# event manager environment server "your server ip address"
# event manager environment udp_port "your udp port"

# event manager applet NMEA
#  event syslog pattern "LINEPROTO-5-UPDOWN: Line protocol on Interface Cellular[0-9\/]+, changed state to up" maxrun 31536000
#  action 010 cli command "enable"
#  action 020 syslog msg "NMEA streaming starting now"
#  action 030 cli command "tclsh flash:stream_NMEA2.tcl $server $udp_port"

# CLI commands required:
# aaa new-model
#  aaa authentication login nologin none
#  aaa authorization exec nologin none 
#  controller Cellular <number>
#   lte gps mode standalone
#   "lte gps nmea ip" for 819.  "lte gps nmea" for all other platforms
# Version 1.1

package require udp
set server [lindex $argv 0]
set sudp_port [lindex $argv 1]
puts "server and port = $server $sudp_port"
set intf [ios_config "int loopback 7" "description DO NOT REMOVE" "ip add 1.2.3.4 255.255.255.255"]
set pt [exec show line | inc NM]
regexp {.?\s+(\d+)\s+TTY} $pt -> line
set cl [exec clear line $line]
set ttyline [ios_config "line $line" "login authentication nologin"]
set transprt [ios_config "line $line" "transport input all"]
set sock [udp_open]
fconfigure $sock -remote [list $server $sudp_port]
after 1000
set IP "1.2.3.4"
set port [expr 2000 + $line]
set fd [socket $IP $port]
while {[gets $fd line] } {
puts -nonewline $sock $line
flush $sock
}
